#!/usr/bin/env python
# -*- coding: utf-8 -*-
#*****************************************************************************
#    Copyright (C) 2006-2007 Serge Weinstock <serge.weinstock@gmail.com>
#  Distributed under the terms of the BSD License.  The full license is in
#  the file COPYING, distributed as part of this software.
#*****************************************************************************
import sys
import release, dcopext
from qt import * #@UnusedWildImport
from kdecore import * #@UnusedWildImport
from kdeui import KMessageBox

def I18N_NOOP(str):
    """Workaround the fact that PyKDE doesn't provide a I18N_NOOP"""
    return str

OPTIONS = [
    ("vv", I18N_NOOP("be verbose")),
    ("+action", I18N_NOOP("the action to perform (copy_path|copy_url|regex_rename|set_folder_icon|clean)")),
    ("!+URLs", I18N_NOOP("the urls to process")),
    ]
__verbose = False

def copy_path(copyPath, options):
    '''
    Copy the paths of the URL to the clipboard
    @param[in] copyPath if True copy the path else copy the URL
    '''

    # let's build the string to copy
    buf = QString()
    for i in xrange(1, options.count()):
        if copyPath:
            if not options.url(i).hasPath():
                continue
            p = options.url(i).path()
        else:
            p = options.url(i).prettyURL()
        if buf: buf += ", "
        buf += p
    # let's use klipper for setting the clipboard
    theApp = KApplication.kApplication()
    klipper = dcopext.DCOPObj("klipper", theApp.dcopClient(), "klipper")
    if not klipper.setClipboardContents(buf)[0]:
        KMessageBox.error(
                None,
                i18n("""Can't set the clipboard contents!\nPlease be sure that klipper is launched"""),
                )

def run(argv):
    """
    Main application loop
    """
    # let's first set up the about data
    aboutdata = KAboutData(
        release.appname,                # app internal name
        I18N_NOOP(release.name),        # app name for display
        release.version,                # version string
        I18N_NOOP(release.description), # short description
        KAboutData.License_BSD,         # license
        release.copyright,              # copyright statement
        None,                           # additional text
        release.url,                    # homepage address
        release.report_bugs_url         # bug report email address
        )
    for author in release.authors.itervalues():
        aboutdata.addAuthor(*author)
    for credit in release.credits.itervalues(): #@UndefinedVariable
        aboutdata.addCredit(*credit)
    # now let's parse the options
    KCmdLineArgs.init(argv, aboutdata, False)
    KCmdLineArgs.addCmdLineOptions(OPTIONS)
    options = KCmdLineArgs.parsedArgs()
    __verbose = options.isSet("vv")
    #
    if options.count() == 0:
        KCmdLineArgs.usage(i18n("No action specified!"))
    #
    app = KApplication() #@UnusedVariable
    #
    action = options.arg(0)
    if action == "copy_path":
        return copy_path(True, options)
    if action == "copy_url":
        return copy_path(False, options)
    if action == "regex_rename":
        import RegexRenameDlgImpl
        return RegexRenameDlgImpl.run(options)
    if action == "set_folder_icon":
        import SetFolderIconDlgImpl
        return SetFolderIconDlgImpl.run(options)
    if action == "clean":
        import CleanDlgImpl
        return CleanDlgImpl.run(options)
    KCmdLineArgs.usage(i18n("Unknown action: '%1'").arg(action))
    return 1

def main(argv=None):
    try:
        if argv is None:
            argv = sys.argv
        return run(argv)
    except SystemExit:
        raise
    except Exception, err:
        if not __verbose:
            from traceback import print_exc
            print_exc(file = sys.stderr)
        print >>sys.stderr, str(err)
        print >>sys.stderr, "for help use --help"
        return 2

if __name__ == "__main__":
    sys.exit(main())
